Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(89)

Unified Diff: remoting/host/desktop_session_connector.h

Issue 2468523003: Pass the desktop session ID to the remoting network process. (Closed)
Patch Set: rebase Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « remoting/host/daemon_process_win.cc ('k') | remoting/host/desktop_session_proxy.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/host/desktop_session_connector.h
diff --git a/remoting/host/desktop_session_connector.h b/remoting/host/desktop_session_connector.h
index c4993b4a308907aa1758e894b0c5bc51cb9a4ea5..6a6af7dcebd83299ab7aa474f4ce148285041042 100644
--- a/remoting/host/desktop_session_connector.h
+++ b/remoting/host/desktop_session_connector.h
@@ -41,10 +41,12 @@ class DesktopSessionConnector {
const ScreenResolution& resolution) = 0;
// Notifies the network process that |terminal_id| is now attached to
// a desktop integration process. |desktop_pipe| is the client end of the pipe
// opened by the desktop process.
virtual void OnDesktopSessionAgentAttached(
int terminal_id,
+ int session_id,
const IPC::ChannelHandle& desktop_pipe) = 0;
// Notifies the network process that the daemon has disconnected the desktop
« no previous file with comments | « remoting/host/daemon_process_win.cc ('k') | remoting/host/desktop_session_proxy.h » ('j') | no next file with comments »
@@ -41,10 +41,12 @@ class DesktopSessionConnector {
const ScreenResolution& resolution) = 0;
// Notifies the network process that |terminal_id| is now attached to
- // a desktop integration process. |desktop_pipe| is the client end of the pipe
- // opened by the desktop process.
+ // a desktop integration process. |session_id| is the id of the desktop
+ // session being attached. |desktop_pipe| is the client end of the pipe opened
+ // by the desktop process.
virtual void OnDesktopSessionAgentAttached(
int terminal_id,

Powered by Google App Engine
This is Rietveld 408576698